==> tuia-ecb-center-api-1.1.0.9-mix-20200320.100144-2-sources.jar: cn/com/duiba/tuia/ecb/center/mix/dto/MixDeviceInfoDTO.java <==
package cn.com.duiba.tuia.ecb.center.mix.dto;

import java.io.Serializable;

/**
 * @Author: xianhongwei
 * @Time: 2020-01-21 11:07
 * @Desc:
 */
public class MixDeviceInfoDTO implements Serializable {
    private static final long serialVersionUID = 3355047498959096848L;

    /**
     * 媒体信息
     */
    private String appKey;

    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 媒体用户id
     */
    private String mediaUserId;

    /**
     * 基站ID
     */
    private String cellularId;

    /**
     * 纬度
     */
    private Double lat;

    /**
     * 经度
     */
    private String lon;

    /**
     * 网络类型: 0- 未知网络 2- 2G 3- 3G 4- 4G 5- 5G 100-WIFI 101—ETHERNET 999--NEW_TYPE
     */
    private Integer connectionType;

    /**
     * 运营商类型: 0- 未知 1- 中国移动 2- 中国电信 3- 中国联通 99-其他运营商
     */
    private Integer operatorType;

    /**
     * iOS设备唯一标识码
     */
    private String idfa;

    /**
     * 安卓设备唯一标识码
     */
    private String imei;

    /**
     * MAC地址
     */
    private String mac;

    /**
     * 安卓设备ID
     */
    private String oaid;

    /**
     * 设备类型  1- 手机 2- 平板
     */
    private Integer deviceType;

    /**
     * 操作系统类型 1- Android 2- iOS
     */
    private Integer osType;

    /**
     * 操作系统版本
     */
    private String osVersion;

    /**
     * 设备厂商
     */
    private String vendor;

    /**
     * 手机品牌
     */
    private String brand;

    /**
     * 设备型号
     */
    private String model;

    /**
     * 设备屏幕高度
     */
    private Integer screenHeight;

    /**
     * 设备屏幕宽度
     */
    private Integer screenWidth;

    /**
     * 像素密度
     */
    private Integer ppi;

    /**
     * imsi
     */
    private String imsi;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getMediaUserId() {
        return mediaUserId;
    }

    public void setMediaUserId(String mediaUserId) {
        this.mediaUserId = mediaUserId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public String getCellularId() {
        return cellularId;
    }

    public void setCellularId(String cellularId) {
        this.cellularId = cellularId;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    public String getLon() {
        return lon;
    }

    public void setLon(String lon) {
        this.lon = lon;
    }

    public Integer getConnectionType() {
        return connectionType;
    }

    public void setConnectionType(Integer connectionType) {
        this.connectionType = connectionType;
    }

    public Integer getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(Integer operatorType) {
        this.operatorType = operatorType;
    }

    public String getIdfa() {
        return idfa;
    }

    public void setIdfa(String idfa) {
        this.idfa = idfa;
    }

    public String getImei() {
        return imei;
    }

    public void setImei(String imei) {
        this.imei = imei;
    }

    public String getMac() {
        return mac;
    }

    public void setMac(String mac) {
        this.mac = mac;
    }

    public String getOaid() {
        return oaid;
    }

    public void setOaid(String oaid) {
        this.oaid = oaid;
    }

    public Integer getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(Integer deviceType) {
        this.deviceType = deviceType;
    }

    public Integer getOsType() {
        return osType;
    }

    public void setOsType(Integer osType) {
        this.osType = osType;
    }

    public String getOsVersion() {
        return osVersion;
    }

    public void setOsVersion(String osVersion) {
        this.osVersion = osVersion;
    }

    public String getVendor() {
        return vendor;
    }

    public void setVendor(String vendor) {
        this.vendor = vendor;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public Integer getScreenHeight() {
        return screenHeight;
    }

    public void setScreenHeight(Integer screenHeight) {
        this.screenHeight = screenHeight;
    }

    public Integer getScreenWidth() {
        return screenWidth;
    }

    public void setScreenWidth(Integer screenWidth) {
        this.screenWidth = screenWidth;
    }

    public Integer getPpi() {
        return ppi;
    }

    public void setPpi(Integer ppi) {
        this.ppi = ppi;
    }

    public String getImsi() {
        return imsi;
    }

    public void setImsi(String imsi) {
        this.imsi = imsi;
    }
}

==> tuia-ecb-center-api-1.1.0.16-mix-20200403.094015-5-sources.jar: cn/com/duiba/tuia/ecb/center/mix/dto/MixDeviceInfoDTO.java <==
package cn.com.duiba.tuia.ecb.center.mix.dto;

import java.io.Serializable;

/**
 * @Author: xianhongwei
 * @Time: 2020-01-21 11:07
 * @Desc:
 */
public class MixDeviceInfoDTO implements Serializable {
    private static final long serialVersionUID = 3355047498959096848L;

    /**
     * 媒体信息
     */
    private String appKey;

    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 媒体用户id
     */
    private String mediaUserId;

    /**
     * 基站ID
     */
    private String cellularId;

    /**
     * 纬度
     */
    private Double lat;

    /**
     * 经度
     */
    private String lon;

    /**
     * 网络类型: 0- 未知网络 2- 2G 3- 3G 4- 4G 5- 5G 100-WIFI 101—ETHERNET 999--NEW_TYPE
     */
    private Integer connectionType;

    /**
     * 运营商类型: 0- 未知 1- 中国移动 2- 中国电信 3- 中国联通 99-其他运营商
     */
    private Integer operatorType;

    /**
     * iOS设备唯一标识码
     */
    private String idfa;

    /**
     * 安卓设备唯一标识码
     */
    private String imei;

    /**
     * MAC地址
     */
    private String mac;

    /**
     * 安卓设备ID
     */
    private String oaid;

    /**
     * 设备类型  1- 手机 2- 平板
     */
    private Integer deviceType;

    /**
     * 操作系统类型 1- Android 2- iOS
     */
    private Integer osType;

    /**
     * 操作系统版本
     */
    private String osVersion;

    /**
     * 设备厂商
     */
    private String vendor;

    /**
     * 手机品牌
     */
    private String brand;

    /**
     * 设备型号
     */
    private String model;

    /**
     * 设备屏幕高度
     */
    private Integer screenHeight;

    /**
     * 设备屏幕宽度
     */
    private Integer screenWidth;

    /**
     * 像素密度
     */
    private Integer ppi;

    /**
     * imsi
     */
    private String imsi;

    /**
     * idfv
     */
    private String idfv;

    /**
     * 安卓id
     */
    private String androidId;


    public String getAndroidId() {
        return androidId;
    }

    public void setAndroidId(String androidId) {
        this.androidId = androidId;
    }

    public String getIdfv() {
        return idfv;
    }

    public void setIdfv(String idfv) {
        this.idfv = idfv;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getMediaUserId() {
        return mediaUserId;
    }

    public void setMediaUserId(String mediaUserId) {
        this.mediaUserId = mediaUserId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public String getCellularId() {
        return cellularId;
    }

    public void setCellularId(String cellularId) {
        this.cellularId = cellularId;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    public String getLon() {
        return lon;
    }

    public void setLon(String lon) {
        this.lon = lon;
    }

    public Integer getConnectionType() {
        return connectionType;
    }

    public void setConnectionType(Integer connectionType) {
        this.connectionType = connectionType;
    }

    public Integer getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(Integer operatorType) {
        this.operatorType = operatorType;
    }

    public String getIdfa() {
        return idfa;
    }

    public void setIdfa(String idfa) {
        this.idfa = idfa;
    }

    public String getImei() {
        return imei;
    }

    public void setImei(String imei) {
        this.imei = imei;
    }

    public String getMac() {
        return mac;
    }

    public void setMac(String mac) {
        this.mac = mac;
    }

    public String getOaid() {
        return oaid;
    }

    public void setOaid(String oaid) {
        this.oaid = oaid;
    }

    public Integer getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(Integer deviceType) {
        this.deviceType = deviceType;
    }

    public Integer getOsType() {
        return osType;
    }

    public void setOsType(Integer osType) {
        this.osType = osType;
    }

    public String getOsVersion() {
        return osVersion;
    }

    public void setOsVersion(String osVersion) {
        this.osVersion = osVersion;
    }

    public String getVendor() {
        return vendor;
    }

    public void setVendor(String vendor) {
        this.vendor = vendor;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public Integer getScreenHeight() {
        return screenHeight;
    }

    public void setScreenHeight(Integer screenHeight) {
        this.screenHeight = screenHeight;
    }

    public Integer getScreenWidth() {
        return screenWidth;
    }

    public void setScreenWidth(Integer screenWidth) {
        this.screenWidth = screenWidth;
    }

    public Integer getPpi() {
        return ppi;
    }

    public void setPpi(Integer ppi) {
        this.ppi = ppi;
    }

    public String getImsi() {
        return imsi;
    }

    public void setImsi(String imsi) {
        this.imsi = imsi;
    }
}
